@@ -39,7 +39,7 @@ TSOCKS_LIBC_DECL(recvmsg, LIBC_RECVMSG_RET_TYPE, LIBC_RECVMSG_SIG)
  */
 static void close_fds(int *fds, size_t count)
 {
-	int i;
+	size_t i;
 
 	for (i = 0; i < count; i++) {
 		tsocks_libc_close(fds[i]);
@@ -50,7 +50,7 @@ static void close_fds(int *fds, size_t count)
  * Torsocks call for recvmsg(2)
  *
  * We only hijack this call to handle the FD passing between process on Unix
- * socket. If an INET/INET6 socket is recevied, we stop everything because at
+ * socket. If an INET/INET6 socket is received, we stop everything because at
  * that point we can't guarantee traffic going through Tor.
  *
  * Note that we don't rely on the given "msg" structure since it's controlled
@@ -92,7 +92,7 @@ LIBC_RECVMSG_RET_TYPE tsocks_recvmsg(LIBC_RECVMSG_SIG)
 
 	do {
 		/* Just peek the data to inspect the payload for fd. */
-		ret = tsocks_libc_recvmsg(sockfd, &msg_hdr, MSG_PEEK);
+		ret = tsocks_libc_recvmsg(sockfd, &msg_hdr, MSG_PEEK | flags);
 	} while (ret < 0 && errno == EINTR);
 	if (ret < 0) {
 		/* Use the current errno set by the call above. */
@@ -124,8 +124,8 @@ LIBC_RECVMSG_RET_TYPE tsocks_recvmsg(LIBC_RECVMSG_SIG)
 		 * chance here of having a crazy high value that could exhaust the
 		 * stack memory.
 		 */
-		size_t sizeof_fds = (cmsg->cmsg_len - sizeof(*cmsg)) / sizeof(int);
-		int i, fds[sizeof_fds];
+		size_t i, sizeof_fds = (cmsg->cmsg_len - sizeof(*cmsg)) / sizeof(int);
+		int fds[sizeof_fds];
 
 		memcpy(&fds, CMSG_DATA(cmsg), sizeof(fds));
 
