@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2008 - Shaun Clowes <delius@progsoc.org> 
+ * Copyright (C) 2000-2008 - Shaun Clowes <delius@progsoc.org>
  * 				 2008-2011 - Robert Hogan <robert@roberthogan.net>
  * 				 	  2013 - David Goulet <dgoulet@ev0ke.net>
  *
@@ -75,7 +75,7 @@ static void clean_exit(int status)
 static void read_env(void)
 {
 	int ret;
-	const char *username, *password, *allow_in, *isolate_pid;
+	const char *username, *password, *allow_in, *isolate_pid, *enable_ipv6, *tor_address, *tor_port;
 
 	if (is_suid) {
 		goto end;
@@ -97,6 +97,30 @@ static void read_env(void)
 		}
 	}
 
+	enable_ipv6 = getenv(DEFAULT_ENABLE_IPV6_ENV);
+	if (enable_ipv6) {
+		ret = conf_file_set_enable_ipv6(enable_ipv6, &tsocks_config);
+		if (ret < 0) {
+			goto error;
+		}
+	}
+
+	tor_address = getenv(DEFAULT_TOR_ADDRESS_ENV);
+	if (tor_address) {
+		ret = conf_file_set_tor_address(tor_address, &tsocks_config);
+		if (ret < 0) {
+			goto error;
+		}
+	}
+
+	tor_port = getenv(DEFAULT_TOR_PORT_ENV);
+	if (tor_port) {
+		ret = conf_file_set_tor_port(tor_port, &tsocks_config);
+		if (ret < 0) {
+			goto error;
+		}
+	}
+
 	username = getenv(DEFAULT_SOCKS5_USER_ENV);
 	password = getenv(DEFAULT_SOCKS5_PASS_ENV);
 	if (!username && !password) {
@@ -141,7 +165,7 @@ static void init_config(void)
 	const char *filename = NULL;
 
 	if (!is_suid) {
-		filename = getenv("TORSOCKS_CONF_FILE");
+		filename = getenv(DEFAULT_CONF_FILE_ENV);
 	}
 
 	ret  = config_file_read(filename, &tsocks_config);
@@ -158,8 +182,8 @@ static void init_config(void)
 	 * are missing.
 	 */
 	if (!tsocks_config.conf_file.tor_address) {
-		tsocks_config.conf_file.tor_address = strdup(DEFAULT_TOR_ADDRESS);
-		if (!tsocks_config.conf_file.tor_address) {
+		ret = conf_file_set_tor_address(DEFAULT_TOR_ADDRESS, &tsocks_config);
+		if (ret < 0) {
 			/* Most likely ENOMEM thus we can't continue. */
 			clean_exit(EXIT_FAILURE);
 		}
@@ -175,6 +199,9 @@ static void init_config(void)
 		tsocks_config.conf_file.onion_mask = atoi(DEFAULT_ONION_ADDR_MASK);
 	}
 
+	/* Handle possible env. variables. */
+	read_env();
+
 	/* Create the Tor SOCKS5 connection address. */
 	ret = connection_addr_set(tsocks_config.conf_file.tor_domain,
 			tsocks_config.conf_file.tor_address,
@@ -187,9 +214,6 @@ static void init_config(void)
 		clean_exit(EXIT_FAILURE);
 	}
 
-	/* Handle possible env. variables. */
-	read_env();
-
 	/* Finalize the SOCKS auth (Isolation) settings. */
 	ret = conf_apply_socks_auth(&tsocks_config);
 	if (ret < 0) {
@@ -217,8 +241,10 @@ static void init_libc_symbols(void)
 	tsocks_libc_close = dlsym(libc_ptr, LIBC_CLOSE_NAME_STR);
 	tsocks_libc_socket = dlsym(libc_ptr, LIBC_SOCKET_NAME_STR);
 	tsocks_libc_syscall = dlsym(libc_ptr, LIBC_SYSCALL_NAME_STR);
-	if (!tsocks_libc_connect || !tsocks_libc_close || !tsocks_libc_socket
-			|| !tsocks_libc_syscall) {
+	tsocks_libc_execve = dlsym(libc_ptr, LIBC_EXECVE_NAME_STR);
+	tsocks_libc_accept4 = dlsym(libc_ptr, LIBC_ACCEPT4_NAME_STR);
+	if (!tsocks_libc_connect || !tsocks_libc_close || !tsocks_libc_socket ||
+			!tsocks_libc_syscall || !tsocks_libc_execve || ! tsocks_libc_accept4) {
 		ERR("Unable to lookup symbols in " LIBC_NAME "(%s)", dlerror());
 		goto error;
 	}
@@ -239,7 +265,7 @@ error_dlopen:
 }
 
 /*
- * Initialize logging subsytem using either the default values or the one given
+ * Initialize logging subsystem using either the default values or the one given
  * by the environment variables.
  */
 static void init_logging(void)
@@ -282,7 +308,7 @@ static void init_logging(void)
 
 	/* After this, it is safe to call any logging macros. */
 
-	DBG("Logging subsytem initialized. Level %d, file %s, time %d",
+	DBG("Logging subsystem initialized. Level %d, file %s, time %d",
 			level, filepath, t_status);
 }
 
@@ -311,7 +337,7 @@ static void tsocks_init(void)
 	init_config();
 
 	/*
-	 * Initalized the onion pool which maps cookie address to hidden service
+	 * Initialized the onion pool which maps cookie address to hidden service
 	 * onion address.
 	 */
 	ret = onion_pool_init(&tsocks_onion_pool,
