@@ -36,6 +36,8 @@
  * Indicate if the thread recv is ready. 0 means no, 1 means yes and -1 means
  * error occurred.
  */
+const int THREAD_RECV_READY_FOR_DATA = 1;
+const int THREAD_RECV_READY_FOR_FDS = 2;
 static volatile int thread_recv_ready;
 
 /* Unix socket for this test. */
@@ -251,8 +253,7 @@ static int connect_unix_sock(const char *pathname)
 
 	memset(&sun, 0, sizeof(sun));
 	sun.sun_family = AF_UNIX;
-	strncpy(sun.sun_path, pathname, sizeof(sun.sun_path));
-	sun.sun_path[sizeof(sun.sun_path) - 1] = '\0';
+	strlcpy(sun.sun_path, pathname, sizeof(sun.sun_path));
 
 	ret = connect(fd, (struct sockaddr *) &sun, sizeof(sun));
 	if (ret < 0) {
@@ -292,8 +293,7 @@ static int create_unix_sock(const char *pathname)
 
 	memset(&sun, 0, sizeof(sun));
 	sun.sun_family = AF_UNIX;
-	strncpy(sun.sun_path, pathname, sizeof(sun.sun_path));
-	sun.sun_path[sizeof(sun.sun_path) - 1] = '\0';
+	strlcpy(sun.sun_path, pathname, sizeof(sun.sun_path));
 
 	/* Unlink the old file if present */
 	(void) unlink(pathname);
@@ -349,7 +349,7 @@ void *thread_recv(void *data)
 	}
 
 	/* Notify we are ready to test. */
-	thread_recv_ready = 1;
+	thread_recv_ready = THREAD_RECV_READY_FOR_DATA;
 
 	new_sock = accept_unix_sock(sock);
 	if (new_sock < 0) {
@@ -369,6 +369,9 @@ void *thread_recv(void *data)
 		strncmp(buf, "hello", sizeof(buf)) == 0,
 		"Data received successfully");
 
+	/* Notify we are ready for next test. */
+	thread_recv_ready = THREAD_RECV_READY_FOR_FDS;
+
 	len = recv_fds_unix_sock(new_sock, fds, 3);
 	if (len < 0) {
 		/* This is suppose to fail with a errno set to EACCESS. */
@@ -391,9 +394,16 @@ error:
 
 void *thread_send(void *data)
 {
-	int sock, fds[3], pipe_fds[2] = {-1, -1};
+	int sock=-1, fds[3], pipe_fds[2] = {-1, -1};
 	ssize_t len;
 
+	/* Active wait for the thread recv to be ready. */
+	while (thread_recv_ready != THREAD_RECV_READY_FOR_DATA) {
+		if (thread_recv_ready == -1) {
+			goto error;
+		}
+	}
+
 	sock = connect_unix_sock(sockpath);
 	if (sock < 0) {
 		fail("Unable to connect to unix socket at %s", sockpath);
@@ -416,6 +426,12 @@ void *thread_send(void *data)
 	 * We are going to pass 3 fds, two of them are pipse in position 0 and 2
 	 * and the inet socket is at position 1.
 	 */
+	/* Active wait for the thread recv to be ready. */
+	while (thread_recv_ready != THREAD_RECV_READY_FOR_FDS) {
+		if (thread_recv_ready == -1) {
+			goto error;
+		}
+	}
 	fds[0] = pipe_fds[0];
 	fds[1] = *((int *)data);
 	fds[2] = pipe_fds[1];
@@ -452,11 +468,11 @@ static void test_inet_socket(void)
 	void *status;
 	pthread_t th[2];
 	struct sockaddr_in addr;
-	const char *ip = "138.201.14.197";
+	const char *ip = "116.202.120.165";
 
 	/*
 	 * First of all, we are going to try to create an inet socket to a public
-	 * known IP being www.torproject.org --> 138.201.14.197.
+	 * known IP being web-fsn-01.torproject.org --> 116.202.120.165.
 	 */
 	inet_sock = socket(AF_INET, SOCK_STREAM, 0);
 	if (inet_sock < 0) {
@@ -483,15 +499,6 @@ static void test_inet_socket(void)
 		goto error;
 	}
 
-	/* Active wait for the thread recv to be ready. */
-	while (thread_recv_ready == 0) {
-		continue;
-	}
-
-	if (thread_recv_ready == -1) {
-		goto error;
-	}
-
 	ret = pthread_create(&th[1], NULL, thread_send, (void *) &inet_sock);
 	if (ret < 0) {
 		fail("pthread_create thread send");
@@ -527,5 +534,5 @@ int main(int argc, char **argv)
 	test_inet_socket();
 
 end:
-	return 0;
+	return exit_status();
 }
